"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const workspace_tools_1 = require("workspace-tools");
const logger_1 = require("../logger");
/**
 * Filters scopedPackages and changedPackages with option to calculate the transitive packages of all
 * @param options
 */
function filterPackages(options) {
    const { scopedPackages, changedPackages, allPackages, deps } = options;
    let filtered = Object.keys(allPackages);
    // If scoped is defined, get scoped packages
    if (typeof scopedPackages !== "undefined") {
        filtered = filtered.filter((pkg) => scopedPackages.includes(pkg));
        logger_1.logger.verbose("filterPackages", `scope: ${scopedPackages.join(",")}`);
    }
    if (typeof changedPackages !== "undefined") {
        filtered = filtered.filter((pkg) => changedPackages.includes(pkg));
        logger_1.logger.verbose("filterPackages", `changed: ${changedPackages.join(",")}`);
    }
    if (deps) {
        filtered = filtered.concat(workspace_tools_1.getTransitiveConsumers(filtered, allPackages));
    }
    const unique = new Set(filtered);
    return [...unique];
}
exports.filterPackages = filterPackages;
